class key_func:
    """
    Instantiate a printing operation 
    The function will print the key
    """
    def __init__(self,key):
        self.key = key 
    
    def key_func(): #defining the function 
        login = "beBybSi8daPgsTp5yx5cHtHpYcrjp5Jq" #the key from max's code
        return login #printing the key
        print(key_func())
print(key_func.key_func())


